@@ -3,22 +3,20 @@ Signals are a simple pub-sub mechanism.
 
 DOMNodes can subscribe to a signal, which will invoke a callback when the signal is published.
 
-This is experimental for now, for internal use. It may be part of the public API in a future release.
-
 """
 
 from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any, Awaitable, Callable, Generic, TypeVar, Union
-from weakref import WeakKeyDictionary
+from weakref import WeakKeyDictionary, ref
 
 import rich.repr
 
 from textual import log
 
 if TYPE_CHECKING:
-    from .dom import DOMNode
-    from .message_pump import MessagePump
+    from textual.dom import DOMNode
+    from textual.message_pump import MessagePump
 SignalT = TypeVar("SignalT")
 
 SignalCallbackType = Union[
@@ -41,17 +39,22 @@ class Signal(Generic[SignalT]):
             owner: The owner of this signal.
             name: An identifier for debugging purposes.
         """
-        self._owner = owner
+        self._owner = ref(owner)
         self._name = name
         self._subscriptions: WeakKeyDictionary[
             MessagePump, list[SignalCallbackType]
         ] = WeakKeyDictionary()
 
     def __rich_repr__(self) -> rich.repr.Result:
-        yield "owner", self._owner
+        yield "owner", self.owner
         yield "name", self._name
         yield "subscriptions", list(self._subscriptions.keys())
 
+    @property
+    def owner(self) -> DOMNode | None:
+        """The owner of this Signal, or `None` if there is no owner."""
+        return self._owner()
+
     def subscribe(
         self,
         node: MessagePump,
@@ -108,9 +111,12 @@ class Signal(Generic[SignalT]):
 
         """
         # Don't publish if the DOM is not ready or shutting down
-        if not self._owner.is_attached or self._owner._pruning:
+        owner = self.owner
+        if owner is None:
             return
-        for ancestor_node in self._owner.ancestors_with_self:
+        if not owner.is_attached or owner._pruning:
+            return
+        for ancestor_node in owner.ancestors_with_self:
             if not ancestor_node.is_running:
                 return
 
